Unreleased changes
------------------

* Remove template artifacts


Version 0
---------

0.1.0 / 2022-03-22
~~~~~~~~~~~~~~~~~~
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
